import BN from 'bn.js';
import { BatchActionV1, PrepareBatch } from './batch';
import { Tonic } from './tonic';
import { L2Order, Orderbook, OrderSide, OrderType } from './types';
import { ActionV1, MarketViewV1, NewOrderParamsV1, TokenType } from './types/v1';
export interface NewOrderParams {
    orderType: OrderType;
    side: OrderSide;
    limitPrice?: number;
    quantity: number;
    maxSpend?: number;
    clientId?: number;
    referrerId?: string;
}
/** L2 Order with BN values converted to decimal numbers */
export declare type NumberL2Order = readonly [number, number];
export interface NumberOrderbook {
    asks: NumberL2Order[];
    bids: NumberL2Order[];
}
export declare function getMidmarketPriceNumber({ bids, asks, }: NumberOrderbook): number | undefined;
export declare class MarketBatchAction implements PrepareBatch {
    private readonly market;
    batch: BatchActionV1;
    constructor(market: Market);
    newOrder(params: NewOrderParams): this;
    cancelOrders(orderIds: string[]): this;
    cancelAllOrders(): this;
    prepare(): ActionV1[];
}
export declare class Market {
    private readonly tonic;
    readonly id: string;
    private readonly _inner;
    readonly baseLotSize: number;
    readonly baseDecimals: number;
    readonly quoteLotSize: number;
    readonly quoteDecimals: number;
    constructor(tonic: Tonic, id: string, _inner: MarketViewV1);
    static load(tonic: Tonic, id: string, contractId: string): Promise<Market>;
    /**
     * @ignore
     */
    get inner(): MarketViewV1;
    /**
     * Base taker fee rate in basis points
     */
    get takerFeeBaseRate(): number;
    /**
     * Net taker fees accrued in the market (does not include maker/referrer
     * rebates)
     */
    get feesAccrued(): BN;
    /**
     * Base maker rebate rate in basis points
     */
    get makerRebateBaseRate(): number;
    /**
     * Maximum number of allowed open orders per user account.
     */
    get maxOrdersPerAccount(): number;
    /**
     * Current number of open orders on the market (buys + sells).
     */
    get totalOpenOrders(): number;
    get baseTokenId(): string;
    get quoteTokenId(): string;
    get baseTokenType(): TokenType;
    get quoteTokenType(): TokenType;
    /**
     * Get minimum price tick as a human readable number.
     */
    get priceTick(): number;
    /**
     * Get minimum quantity tick as a human readable number.
     */
    get quantityTick(): number;
    /**
     * For internal use
     * @ignore
     */
    toNewOrderParamsV1(params: NewOrderParams): NewOrderParamsV1;
    makePlaceOrderTransaction(params: NewOrderParams): import("@tonic-foundation/transaction/lib/shim").StandardNearFunctionCall;
    placeOrder(params: NewOrderParams): Promise<{
        response: import("./types/v1").OrderResultV1;
        executionOutcome: import("@near-wallet-selector/core").FinalExecutionOutcome;
    }>;
    /**
     * Same as Tonic.getOrderbook
     */
    getOrderbookRaw(depth?: number): Promise<Orderbook>;
    /**
     * Return the orderbook with prices and quantities converted to human-readable numbers,
     * eg, an order for 0.1 BTC @ 54321.00 USDC will be returned as [54321, 01].
     */
    getOrderbook(depth?: number): Promise<NumberOrderbook>;
    /** @ignore */
    toNumberL2Order(order: L2Order): NumberL2Order;
    /** @ignore */
    withNumberValues(orderbook: Orderbook): NumberOrderbook;
    createBatchAction(): MarketBatchAction;
    /**
     * Given price as a number, return a decimal-padded BN optionally floored to
     * the nearest quote lot size.
     *
     * If round_trailing_decimals_up===true, the least
     * significant digit + trailing digits are rounded up their ceiling.
     */
    priceNumberToBn(price: number, floor?: boolean, round_trailing_decimals_up?: boolean): BN;
    /**
     * Given price as a number, return an equivalent BN of lots.
     */
    priceNumberToBnLots(price: number, floor?: boolean): BN;
    /**
     * Given price as a decimal-padded BN, return a decimal.
     */
    priceBnToNumber(price: BN, precision?: number): number;
    /**
     * Given order size as a number, return a decimal-padded BN optionally floored
     * to the nearest base lot size.
     */
    quantityNumberToBn(quantity: number, floor?: boolean): BN;
    /**
     * Given order size as a number, return an equivalent BN of lots.
     */
    quantityNumberToBnLots(quantity: number, floor?: boolean): BN;
    /**
     * Given quantity as a decimal-padded BN, return a decimal.
     */
    quantityBnToNumber(quantity: BN, precision?: number): number;
}
